@@ -19,36 +19,28 @@
 #ifndef ALARM_H
 #define ALARM_H
 
-#include "accelerometer.h"
-
 #include <QtGui>
 
+class Backend;
+
+//abstract base class for alarm modules
 class Alarm : public QDialog {
 	Q_OBJECT
 public:
-	Alarm(QWidget *parent = 0);
-	~Alarm();
+	Alarm(QWidget *parent);
+	virtual ~Alarm() = 0;
+	static Alarm* getModuleInstance(QWidget *parent = 0);
 protected:
-	void closeEvent(QCloseEvent*);
+	virtual void closeEvent(QCloseEvent*);
 protected slots:
-	void accelUpdate(int, int, int);
-	void initialize();
-	void snooze();
-	void start();
-	void stop();
-private:
-	QLabel *label;
-	QPushButton *snooze_button;
-
-	Accelerometer *accel;
+	virtual void restart();
+	virtual void snooze();
+protected:
+	Backend *backend;
 	QTime alarm_started;
-	bool alarm_playing;
+	int alarm_timeout;
 	bool snoozing;
-	int alarm_timeout, inactivity_timeout;
-	quint32 notify_id;
+	QTime snooze_till;
 	int num_snooze;
-
-	int lastx, lasty, lastz;
-	QTime last_active;
 };
 #endif
