@@ -11,14 +11,17 @@ int main(int argc, char* argv[])
 	QCoreApplication::setOrganizationName("EvilAlarm");
 	QCoreApplication::setApplicationName("EvilAlarm");
 
+	//ensure destructors are called
+	QScopedPointer<QWidget> widget_pointer;
+
 	if(QCoreApplication::arguments().contains(QString("--daemon"))) {
 		new Daemon;
 	} else if(QCoreApplication::arguments().contains(QString("--wakeup"))) {
-		QWidget *widget = new Alarm;
-		widget->show();
+		widget_pointer.reset(Alarm::getModuleInstance());
+		widget_pointer->show();
 	} else {
-		QWidget *widget = new MainWindow;
-		widget->show();
+		widget_pointer.reset(new MainWindow);
+		widget_pointer->show();
 	}
 	return app.exec();
 }
